@@ -2,11 +2,12 @@
 #'
 #' @noRd
 smtp_settings <- function() {
+  # use_ssl means STARTTLS, not smtps://
   dplyr::tribble(
-    ~short_name,   ~server,                    ~port, ~use_ssl, ~use_tls, ~authenticate, ~user,   ~long_name,
-    "gmail",       "smtp.gmail.com",           465,   TRUE,     FALSE,    TRUE,          "email", "Gmail",
-    "outlook",     "smtp-mail.outlook.com",    587,   FALSE,    TRUE,     TRUE,          "email", "Outlook.com",
-    "office365",   "smtp.office365.com",       587,   FALSE,    TRUE,     TRUE,          "email", "Office365.com",
+    ~short_name,   ~server,                    ~port, ~use_ssl, ~user,   ~long_name,
+    "gmail",       "smtp.gmail.com",           465,   FALSE,    "email", "Gmail",
+    "outlook",     "smtp-mail.outlook.com",    587,   TRUE,     "email", "Outlook.com",
+    "office365",   "smtp.office365.com",       587,   TRUE,     "email", "Office365.com",
   )
 }
 
