@@ -14,19 +14,29 @@ test_that("creating a base64-encoded image is possible", {
   # Create an image as an <img> tag
   img_file_html <- add_image(file = img_file_path)
 
+  snapshot(img_file_html)
+
   # Expect a base64 PNG within `img` tags
-  expect_true(
-    grepl("<img cid=\".*?__test_image.png\" src=\"data:image/png;base64,.*\" .*?/>", img_file_html)
-  )
+  expect_true(grepl("<img src=\"data:image/png;base64,.*\" (.|\n)*?>", img_file_html))
 
   # Create an image as an <img> tag, with alt text
-  img_file_html <- add_image(file = img_file_path, alt = "A test image")
+  img_file_html2 <- add_image(file = img_file_path, alt = "A test image")
+
+  snapshot(img_file_html2)
 
   # Expect a base64 PNG within `img` tags
   # and the specified alt text
-  expect_true(
-    grepl("<img cid=\".*?__test_image.png\" src=\"data:image/png;base64,.*\" .*? alt=\"A test image\"/>", img_file_html)
-  )
+  expect_true(grepl("<img src=\"data:image/png;base64,.*\".*alt=\"A test image\"(.|\n)*?>", img_file_html2))
+
+  # align works
+  img_file_html3 <- add_image(file = img_file_path, alt = "A test image", align = "inline")
+
+  snapshot(img_file_html3)
+
+  # float takes precedence over align
+  img_file_html4 <- add_image(file = img_file_path, alt = "A test image", align = "left", float = "right")
+
+  snapshot(img_file_html4)
 })
 
 test_that("creating a base64-encoded ggplot is possible", {
@@ -52,5 +62,5 @@ test_that("creating a base64-encoded ggplot is possible", {
 
   # Expect a base64 PNG within `img` tags
   expect_true(
-    grepl("<img cid=\".*?__temp_ggplot.png\" src=\"data:image/png;base64,.*\" .*?/>", plot_html))
+    grepl("<img src=\"data:image/png;base64,.*\" .*?/>", plot_html))
 })
